%define systemd (0%{?fedora} && 0%{?fedora} >= 18) || (0%{?rhel} && 0%{?rhel} >= 7)
%define daemon_group apache

%define core_version 0.8.0
%define merlin_version 2.1.0
%define widget_services 1.0.2
%define livestatus_version 1.2.1
%define monitor_major %(echo %{version}|cut -d"." -f 1)
%define monitor_minor %(echo %{version}|cut -d"." -f 2)

Summary: op5 Monitor release and package configuration.
Name: op5-monitor-release
Version: %{op5version}
Release: %{op5release}%{?dist}
Group: op5/monitor
License: op5 Software License
Prefix: /etc/yum.repos.d
Source0: %name-%version.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}
BuildArch: noarch

Requires: op5-monitor = %version
Requires: op5-release

%description
Metapackage for op5 Monitor product that installs the repository configuration
for online updates

%package -n op5-monitor
Summary: contains packages included in a particular release of op5 Monitor
Group: op5/Monitor
Requires: graphviz >= 2.40.1
Requires: merlin >= %merlin_version
Requires: merlin-apps >= %merlin_version
Requires: monitor-backup >= 3.2.12
Requires: monitor-config >= 4.0.0
Requires: monitor-geomap >= 2.2.2
Requires: monitor-http-api >= 1.1.0
Requires: monitor-livestatus >= %livestatus_version
Requires: monitor-management-packs
Requires: monitor-merlin >= %merlin_version
Requires: monitor-nacoma >= 4.3.4
Requires: monitor-nagvis >= 1.5.9.9.2
Requires: monitor-ninja >= 3.0.0
Requires: monitor-notify >= 4.0.0
Requires: monitor-op5auth >= 1.1.10
Requires: monitor-op5reports >= 1.2.3
Requires: monitor-pnp >= 0.6.7.9
Requires: monitor-widget-getting-started
Requires: monitor-widget-hostperf >= 1.1.0
Requires: monitor-widget-merlin-node-status >= 0.0.7
Requires: monitor-widget-services >= %widget_services
Requires: monitor-widget-services-critical-acknowledged >= %widget_services
Requires: monitor-widget-services-critical-unacknowledged >= %widget_services
Requires: monitor-widget-synergy >= 1.2.0
Requires: monitor-wizard
Requires: op5-abrt-config
Requires: op5-dokuwiki >= 2018.f
Requires: op5-logger
Requires: op5-monitor-product-config
Requires: op5-naemon >= %core_version
Requires: op5-snmpd-config
Requires: op5-synergy-luapack >= 1.0.2
Requires: op5-synergy-processor >= 1.1.0
Requires: op5-trapper >= 6.3
Requires: php-op5lib >= 1.0.0
Requires: smsacknowledge >= 2.0.0
Requires: smspassivecheck >= 1.2.1
Requires: smsreceiver >= 1.2.1
Requires: unixcat >= %livestatus_version
%if %systemd
BuildRequires: systemd
Provides: op5-systemd-preset = %version
Obsoletes: op5-systemd-preset < %version
%endif

# plugins-community and plugins-metadata have their contents moved to
# individual plugin repo/packages. After moving a plugin we need to bump the
# version of the old packages in order to not get any conflics. plugins-op5 is
# the metapackage that includes all the plugins we would like our customers to
# have. Here we include that package to have it in the default installation.
# Extracted check_wmi_plus to its own repo and removed everything about it from
# the community and metadata package at these versions.
Requires: plugins-community > 2016.i.1
Requires: plugins-metadata > 2016.j.1
Requires: plugins-nagios >= 2.6.1
Requires: plugins-op5 > 2016.a.1
Requires: op5common >= 1.1.10
Requires: op5-nrpe-client >= 2.13.0
Requires: op5license
Requires: portal
Requires: op5-nrpe
Requires: op5backup
Requires: op5-self-monitoring
%if 0%{?rhel} <= 6
Requires: op5kad >= 0.0.3
Requires: op5config
%endif
# This is actually a plugin, it just isn't named or located like one
Requires: webinject >= 1.41

Requires: op5-community-release

Requires: MySQL-python
Requires: php-cli
Obsoletes: monitor-manual < %version

%description -n op5-monitor
This meta package depends on all the packages required by op5 Monitor. It exists to allow for offline installations of the product.

%package test
Summary: empty dummy package that depends on op5-mysql and needed packages
Group: op5/Monitor
Requires: op5-mysql
Requires: op5-httpd
Requires: op5backup
%if %systemd
Requires: python-pip
Requires: firewalld
%endif

%description test
This is an empty package that satisfies the dependencies of op5-monitor-release
tests to verify


%prep
%setup -q

%install
rm -rf %buildroot

%if %systemd
mkdir --parents %{buildroot}%{_unitdir}
cp op5-monitor.service %{buildroot}%{_unitdir}/op5-monitor.service
%endif

install -d %buildroot%_docdir/op5-monitor-release-test-%{version}
install README.op5-monitor-release-test %buildroot%_docdir/op5-monitor-release-test-%{version}/README

install -d %buildroot%_docdir/op5-monitor-release-%{version}
install README.op5-monitor-release-test %buildroot%_docdir/op5-monitor-release-%{version}/README

mkdir -p %buildroot/%_sysconfdir/op5-backup/modules/external
install -m 644 backup/op5-monitor %buildroot%_sysconfdir/op5-backup/modules/external/op5-monitor
install -m 644 backup/op5-monitor.charch %buildroot%_sysconfdir/op5-backup/modules/external/op5-monitor.charch

install -m 644 op5-monitor-release %buildroot%_sysconfdir/op5-monitor-release

# Read MARKETING_VERSION file created from ci_config.yml pre step.
MARKETING_VERSION=$(cat MARKETING_VERSION)
if [ %release == "op5.1" ]; then
  if [ -z "$MARKETING_VERSION" ]; then
    echo "No marketing_version set, please set correct tag in git"
    exit 1
  fi
  echo "VERSION=$MARKETING_VERSION" > %buildroot%_sysconfdir/op5-monitor-release
else
  if [ -z "$MARKETING_VERSION" ]; then
    echo "VERSION=%version-%release" > %buildroot%_sysconfdir/op5-monitor-release
  else
    echo "VERSION=$MARKETING_VERSION" > %buildroot%_sysconfdir/op5-monitor-release
  fi
fi

%post -n op5-monitor-release
# this file collides with our backup module, so delete it if it exists
if [ -f /etc/op5-backup/modules/legacy/nagios-state ]; then
	rm /etc/op5-backup/modules/legacy/nagios-state
fi

%if %systemd
%post -n op5-monitor
systemctl daemon-reload > /dev/null 2>&1 || :
systemctl enable op5-monitor.service > /dev/null 2>&1 || :
systemctl start op5-monitor.service > /dev/null 2>&1 || :
%else
service abrtd status >/dev/null
RET=$?
if [ $RET -gt 0 ]; then
	service abrtd start
fi
%endif


%if %systemd
%preun -n op5-monitor
%systemd_preun op5-monitor.service
%endif


%if %systemd
%postun -n op5-monitor
%systemd_postun op5-monitor.service
%endif

%files
%defattr(-, root, root)
%doc %_docdir/op5-monitor-release-%{version}/README

%files -n op5-monitor
%defattr(-, root, root)
%_sysconfdir/op5-monitor-release
%_sysconfdir/op5-backup/modules/external/*
%if %systemd
%attr(644,root,root) %{_unitdir}/op5-monitor.service
%endif


%files test
%defattr(-, root, root)
%doc %_docdir/op5-monitor-release-test-%{version}/README

%clean
rm -rf %buildroot

%changelog
* Tue Nov 7 2017 Robin Engström <robin.engstrom@op5.com>
- Added OP5-monitor systemd service file

* Wed Oct 1 2008 Andreas Ericsson <ae@op5.se>
- Split release and repo-config into separate packages.

* Tue Sep 11 2007 Peter Ostlin <peter@op5.se>
- Initial creation
